@@ -1,15 +1,20 @@
 """ IndieAuth token endpoint """
 
+import functools
 import json
 import logging
 import time
 import typing
+import urllib.parse
 
+import arrow
 import flask
 import itsdangerous
 import requests
 import werkzeug.exceptions as http_error
+from pony import orm
 
+from . import model, utils
 from .config import config
 
 LOGGER = logging.getLogger(__name__)
@@ -23,7 +28,7 @@ def signer(context: str):
 
 def get_token(id_url: str, lifetime: int, scope: str = None, context: str = '') -> str:
     """ Gets a signed token for the given identity"""
-    token = {'me': id_url}
+    token = {'me': utils.canonicize_url(id_url)}
     if scope:
         token['scope'] = scope
 
@@ -81,6 +86,28 @@ def send_auth_ticket(subject: str,
     current_app.indexer.submit(_submit)
 
 
+@orm.db_session()
+def log_grant(identity: str):
+    """ Update the user table with the granted token """
+    import authl.handlers.indieauth
+
+    values = {
+        'last_token': arrow.utcnow().datetime,
+    }
+
+    profile = authl.handlers.indieauth.get_profile(identity)
+    if profile:
+        values['profile'] = profile
+
+    record = model.KnownUser.get(user=identity)
+    if record:
+        record.set(**values)
+    else:
+        record = model.KnownUser(user=identity,
+                                 **values,
+                                 last_seen=arrow.utcnow().datetime)
+
+
 def redeem_grant(grant_type: str, auth_token: str):
     """ Redeem a grant from a provided redemption ticket """
     grant = parse_token(auth_token, grant_type)
@@ -90,6 +117,7 @@ def redeem_grant(grant_type: str, auth_token: str):
     scope = grant.get('scope', '')
 
     token = get_token(grant['me'], config.token_lifetime, scope)
+
     response = {
         'access_token': token,
         'token_type': 'Bearer',
@@ -103,16 +131,50 @@ def redeem_grant(grant_type: str, auth_token: str):
     if scope:
         response['scope'] = scope
 
+    log_grant(grant['me'])
+
     return json.dumps(response), {'Content-Type': 'application/json'}
 
 
+@functools.lru_cache()
+def get_ticket_endpoint(me_url: str):
+    """ Get the IndieAuth Ticket Auth endpoint and the canonical identity URL """
+    LOGGER.debug("get_ticket_endpoint %s", me_url)
+    import authl.handlers.indieauth
+    from bs4 import BeautifulSoup
+
+    req = authl.utils.request_url(me_url)
+    content = BeautifulSoup(req.text, 'html.parser')
+
+    if req.links and 'canonical' in req.links:
+        canonical_url = req.links['canonical']['url']
+    else:
+        link = content.find('link', rel='canonical')
+        if link:
+            canonical_url = urllib.parse.urljoin(me_url, link.get('href'))
+        else:
+            canonical_url = me_url
+
+    if utils.canonicize_url(canonical_url) != utils.canonicize_url(me_url):
+        # We have a rel="canonical" which mismatches the provided identity URL
+        LOGGER.debug("%s -> canonical=%s", me_url, canonical_url)
+        endpoint, me_url = authl.handlers.indieauth.find_endpoint(canonical_url,
+                                                                  rel='ticket_endpoint')
+    else:
+        # Use our fetch to seed Authl's endpoint fetch and get that instead
+        endpoints, me_url = authl.handlers.indieauth.find_endpoints(me_url,
+                                                                    req.links, content)
+        endpoint = endpoints.get('ticket_endpoint')
+
+    LOGGER.debug("%s %s", me_url, endpoint)
+    return endpoint, me_url
+
+
 def ticket_request(me_url: str, scope: str):
     """ Initiate a ticket request """
-    import authl.handlers.indieauth
 
     try:
-        endpoint, _ = authl.handlers.indieauth.find_endpoint(me_url,
-                                                             rel='ticket_endpoint')
+        endpoint, me_url = get_ticket_endpoint(utils.canonicize_url(me_url))
     except RuntimeError:
         endpoint = None
     if not endpoint:
